==> apache-camel-3.4.6-src.zip: apache-camel-3.4.6/components/camel-aws-swf/src/test/java/org/apache/camel/component/aws/swf/SWFComponentClientRegistryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws.swf;

import org.apache.camel.test.junit4.CamelTestSupport;
import org.junit.Test;

public class SWFComponentClientRegistryTest extends CamelTestSupport {

    @Test
    public void createEndpointWithMinimalSWFClientConfiguration() throws Exception {

        AmazonSWFClientMock awsSWFClient = new AmazonSWFClientMock();
        context.getRegistry().bind("awsSWFClient", awsSWFClient);
        SWFComponent component = context.getComponent("aws-swf", SWFComponent.class);
        SWFEndpoint endpoint = (SWFEndpoint) component.createEndpoint("aws-swf://workflow");

        assertNotNull(endpoint.getConfiguration().getAmazonSWClient());
    }
    
    @Test(expected = IllegalArgumentException.class)
    public void createEndpointWithMinimalSWFClientMisconfiguration() throws Exception {

        SWFComponent component = context.getComponent("aws-swf", SWFComponent.class);
        SWFEndpoint endpoint = (SWFEndpoint) component.createEndpoint("aws-swf://workflow");
    }
}

==> apache-camel-3.7.2-src.zip: apache-camel-3.7.2/components/camel-aws-swf/src/test/java/org/apache/camel/component/aws/swf/SWFComponentClientRegistryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws.swf;

import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.assertThrows;

public class SWFComponentClientRegistryTest extends CamelTestSupport {

    @Test
    public void createEndpointWithMinimalSWFClientConfiguration() throws Exception {

        AmazonSWFClientMock awsSWFClient = new AmazonSWFClientMock();
        context.getRegistry().bind("awsSWFClient", awsSWFClient);
        SWFComponent component = context.getComponent("aws-swf", SWFComponent.class);
        SWFEndpoint endpoint = (SWFEndpoint) component.createEndpoint("aws-swf://workflow");

        assertNotNull(endpoint.getConfiguration().getAmazonSWClient());
    }

    @Test
    public void createEndpointWithMinimalSWFClientMisconfiguration() throws Exception {

        SWFComponent component = context.getComponent("aws-swf", SWFComponent.class);
        assertThrows(IllegalArgumentException.class,
                () -> component.createEndpoint("aws-swf://workflow"));
    }
}
